cookiecutter\_python package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cookiecutter_python.hooks



Module contents
---------------

.. automodule:: cookiecutter_python
   :members:
   :undoc-members:
   :show-inheritance:
